Enum csfml_graphics_sys::sfBlendFactor
[−]
[src]
pub enum sfBlendFactor {
sfBlendFactorZero,
sfBlendFactorOne,
sfBlendFactorSrcColor,
sfBlendFactorOneMinusSrcColor,
sfBlendFactorDstColor,
sfBlendFactorOneMinusDstColor,
sfBlendFactorSrcAlpha,
sfBlendFactorOneMinusSrcAlpha,
sfBlendFactorDstAlpha,
sfBlendFactorOneMinusDstAlpha,
}BlendMode factor types
Variants
sfBlendFactorZerosfBlendFactorOnesfBlendFactorSrcColorsfBlendFactorOneMinusSrcColorsfBlendFactorDstColorsfBlendFactorOneMinusDstColorsfBlendFactorSrcAlphasfBlendFactorOneMinusSrcAlphasfBlendFactorDstAlphasfBlendFactorOneMinusDstAlphaTrait Implementations
impl Copy for sfBlendFactor[src]
impl Debug for sfBlendFactor[src]
impl Ord for sfBlendFactor[src]
fn cmp(&self, __arg_0: &sfBlendFactor) -> Ordering
This method returns an Ordering between self and other. Read more
impl PartialOrd for sfBlendFactor[src]
fn partial_cmp(&self, __arg_0: &sfBlendFactor) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Eq for sfBlendFactor[src]
impl PartialEq for sfBlendFactor[src]
fn eq(&self, __arg_0: &sfBlendFactor) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Clone for sfBlendFactor[src]
fn clone(&self) -> sfBlendFactor
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more