Enum csfml_graphics_sys::sfPrimitiveType
[−]
[src]
pub enum sfPrimitiveType {
sfPoints,
sfLines,
sfLinesStrip,
sfTriangles,
sfTrianglesStrip,
sfTrianglesFan,
sfQuads,
}Types of primitives that a VertexArray can render
Points and lines have no area, therefore their thickness will always be 1 pixel, regardless the current transform and view.
Variants
sfPointsList of individual points.
sfLinesList of individual lines.
sfLinesStripList of connected lines, a point uses the previous point to form a line.
sfTrianglesList of individual triangles.
sfTrianglesStripList of connected triangles, a point uses the two previous points to form a triangle.
sfTrianglesFanList of connected triangles, a point uses the common center and the previous point to form a triangle.
sfQuadsList of individual quads.